from web_foundation.kernel import Isolate


class ScheduledExecutor(Isolate):
    def _close(self):
        pass

    async def _run(self):
        pass
